module.exports = defineTest({
	description: 'supports directly accessing import.meta'
});
